@@ -420,7 +420,7 @@ class CreateServer(command.ShowOne):
             volume = utils.find_resource(
                 volume_client.volumes,
                 parsed_args.volume,
-            ).id
+            )
 
         # Lookup parsed_args.flavor
         flavor = utils.find_resource(compute_client.flavors,
@@ -458,7 +458,11 @@ class CreateServer(command.ShowOne):
         if volume:
             # When booting from volume, for now assume no other mappings
             # This device value is likely KVM-specific
-            block_device_mapping = {'vda': volume}
+            if hasattr(volume, 'volume_image_metadata') and \
+                    volume.volume_image_metadata.get('root_device_name') == 'sda':
+                block_device_mapping = {'sda': volume.id}
+            else:
+                block_device_mapping = {'vda': volume.id}
         else:
             for dev_map in parsed_args.block_device_mapping:
                 dev_key, dev_vol = dev_map.split('=', 1)
@@ -1782,7 +1786,7 @@ class UnshelveServer(command.Command):
 
 
 class AddFixedIP(command.Command):
-    _description = _("Add fixed IP address to server")
+    _description = _("Attach interface to server by fixed IP address")
 
     def get_parser(self, prog_name):
         parser = super(AddFixedIP, self).get_parser(prog_name)
@@ -1821,7 +1825,7 @@ class AddFixedIP(command.Command):
 
 
 class RemoveFixedIP(command.Command):
-    _description = _("Remove fixed IP address from server")
+    _description = _("Detach interface from server by fixed IP address")
 
     def get_parser(self, prog_name):
         parser = super(RemoveFixedIP, self).get_parser(prog_name)
@@ -1897,7 +1901,7 @@ class ListPort(command.Lister):
 
 
 class AddPort(command.Command):
-    _description = _("Add port to server")
+    _description = _("Attach interface to server by port")
 
     def get_parser(self, prog_name):
         parser = super(AddPort, self).get_parser(prog_name)
@@ -1930,7 +1934,7 @@ class AddPort(command.Command):
 
 
 class RemovePort(command.Command):
-    _description = _("Remove port from server")
+    _description = _("Detach interface from server by port")
 
     def get_parser(self, prog_name):
         parser = super(RemovePort, self).get_parser(prog_name)
