@@ -64,6 +64,7 @@ def _format_image(image):
 
 
 class CopyImage(command.ShowOne):
+    _description = _("Copy of image")
     def get_parser(self, prog_name):
         parser = super(CopyImage, self).get_parser(prog_name)
         parser.add_argument(
@@ -96,6 +97,7 @@ class CopyImage(command.ShowOne):
 
 
 class CancelCopyImage(command.ShowOne):
+    _description = _("Cancel copy of image")
     def get_parser(self, prog_name):
         parser = super(CancelCopyImage, self).get_parser(prog_name)
         parser.add_argument(
@@ -116,6 +118,7 @@ class CancelCopyImage(command.ShowOne):
 
 
 class ListCopyImage(command.Lister):
+    _description = _("List copy-jobs of image")
     def get_parser(self, prog_name):
         parser = super(ListCopyImage, self).get_parser(prog_name)
         return parser
@@ -140,6 +143,7 @@ class ListCopyImage(command.Lister):
 
 
 class ShowCopyImage(command.ShowOne):
+    _description = _("Show copy-job of image")
     def get_parser(self, prog_name):
         parser = super(ShowCopyImage, self).get_parser(prog_name)
         parser.add_argument(
@@ -160,6 +164,7 @@ class ShowCopyImage(command.ShowOne):
 
 
 class UpdateImageMember(command.ShowOne):
+    _description = _("Update member of image")
     def get_parser(self, prog_name):
         parser = super(UpdateImageMember, self).get_parser(prog_name)
         parser.add_argument(
@@ -324,12 +329,17 @@ class CreateImage(command.ShowOne):
         public_group.add_argument(
             "--public",
             action="store_true",
-            help="Image is accessible to the public",
+            help="Public to all users",
         )
         public_group.add_argument(
             "--private",
             action="store_true",
-            help="Image is inaccessible to the public (default)",
+            help="Private to other users",
+        )
+        public_group.add_argument(
+            "--shared",
+            action="store_true",
+            help="Shareable with other users (Shared members are not set by default)",
         )
         parser.add_argument(
             "--property",
@@ -414,6 +424,8 @@ class CreateImage(command.ShowOne):
             kwargs['visibility'] = 'public'
         if parsed_args.private:
             kwargs['visibility'] = 'private'
+        if parsed_args.shared:
+            kwargs['visibility'] = 'shared'
 
         # Handle deprecated --owner option
         project_arg = parsed_args.project
