@@ -21,6 +21,7 @@ ROWS_FOR_SHOW = [
     'Tenant ID',
     'Algorithm',
     'Persistence',
+    'Idle timeout',
     'Sorry page url',
     'Source NAT',
     'Certificate ID',
@@ -38,6 +39,7 @@ ROWS_FOR_CHANGES = [
 ROWS_FOR_SHOW_STAGED = [
     'Algorithm',
     'Persistence',
+    'Idle timeout',
     'Sorry page url',
     'Source NAT',
     'Certificate ID',
@@ -49,6 +51,7 @@ ROWS_FOR_SHOW_STAGED = [
 
 
 class ListPolicy(command.Lister):
+    _description = _("List policys of managed load balancer")
 
     def get_parser(self, prog_name):
         parser = super(ListPolicy, self).get_parser(prog_name)
@@ -67,6 +70,7 @@ class ListPolicy(command.Lister):
             'Load Balancer ID',
             'Algorithm',
             'Persistence',
+            'Idle timeout',
             'Sorry page url',
             'Source NAT',
             'Certificate ID',
@@ -87,6 +91,7 @@ class ListPolicy(command.Lister):
 
 
 class ShowPolicy(command.ShowOne):
+    _description = _("Show policy of managed load balancer")
 
     def get_parser(self, prog_name):
         parser = super(ShowPolicy, self).\
@@ -120,6 +125,7 @@ class ShowPolicy(command.ShowOne):
 
 
 class CreatePolicy(command.ShowOne):
+    _description = _("Create new policy of managed load balancer")
 
     def get_parser(self, prog_name):
         parser = super(CreatePolicy, self). \
@@ -163,6 +169,13 @@ class CreatePolicy(command.ShowOne):
             help=_('Persistence setting of the policy'),
         )
 
+        parser.add_argument(
+            '--idle-timeout',
+            metavar='<idle-timeout>',
+            type=int,
+            help=_('The duration (in seconds) during which a session is allowed to remain inactive'),
+        )
+
         parser.add_argument(
             '--sorry-page-url',
             metavar='<sorry-page-url>',
@@ -239,6 +252,7 @@ class CreatePolicy(command.ShowOne):
             tags=tags,
             algorithm=parsed_args.algorithm,
             persistence=parsed_args.persistence,
+            idle_timeout=parsed_args.idle_timeout,
             sorry_page_url=parsed_args.sorry_page_url,
             certificate_id=parsed_args.certificate_id,
             source_nat=parsed_args.source_nat,
@@ -253,6 +267,7 @@ class CreatePolicy(command.ShowOne):
 
 
 class DeletePolicy(command.Command):
+    _description = _("Delete policy of managed load balancer")
 
     def get_parser(self, prog_name):
         parser = super(DeletePolicy, self). \
@@ -272,6 +287,7 @@ class DeletePolicy(command.Command):
 
 
 class UpdatePolicy(command.ShowOne):
+    _description = _("Update policy of managed load balancer")
 
     def get_parser(self, prog_name):
         parser = super(UpdatePolicy, self). \
@@ -350,6 +366,7 @@ class UpdatePolicy(command.ShowOne):
 
 
 class CreateStagedPolicyConfiguration(command.ShowOne):
+    _description = _("Create new staged policy of managed load balancer")
 
     def get_parser(self, prog_name):
         parser = super(CreateStagedPolicyConfiguration, self). \
@@ -380,6 +397,13 @@ class CreateStagedPolicyConfiguration(command.ShowOne):
             help=_('Persistence setting of the policy'),
         )
 
+        parser.add_argument(
+            '--idle-timeout',
+            metavar='<idle-timeout>',
+            type=int,
+            help=_('The duration (in seconds) during which a session is allowed to remain inactive'),
+        )
+
         parser.add_argument(
             '--sorry-page-url',
             metavar='<sorry-page-url>',
@@ -437,6 +461,7 @@ class CreateStagedPolicyConfiguration(command.ShowOne):
             parsed_args.policy,
             algorithm=parsed_args.algorithm,
             persistence=parsed_args.persistence,
+            idle_timeout=parsed_args.idle_timeout,
             sorry_page_url=parsed_args.sorry_page_url,
             certificate_id=parsed_args.certificate_id,
             source_nat=parsed_args.source_nat,
@@ -450,6 +475,7 @@ class CreateStagedPolicyConfiguration(command.ShowOne):
 
 
 class CancelStagedPolicyConfiguration(command.Command):
+    _description = _("Cancel staged policy of managed load balancer")
 
     def get_parser(self, prog_name):
         parser = super(CancelStagedPolicyConfiguration, self). \
@@ -468,6 +494,7 @@ class CancelStagedPolicyConfiguration(command.Command):
 
 
 class ShowStagedPolicyConfiguration(command.ShowOne):
+    _description = _("Show staged policy of managed load balancer")
 
     def get_parser(self, prog_name):
         parser = super(ShowStagedPolicyConfiguration, self).\
@@ -490,6 +517,7 @@ class ShowStagedPolicyConfiguration(command.ShowOne):
 
 
 class UpdateStagedPolicyConfiguration(command.ShowOne):
+    _description = _("Update staged policy of managed load balancer")
 
     def get_parser(self, prog_name):
         parser = super(UpdateStagedPolicyConfiguration, self). \
@@ -520,6 +548,13 @@ class UpdateStagedPolicyConfiguration(command.ShowOne):
             help=_('Persistence setting of the policy'),
         )
 
+        parser.add_argument(
+            '--idle-timeout',
+            metavar='<idle-timeout>',
+            type=int,
+            help=_('The duration (in seconds) during which a session is allowed to remain inactive'),
+        )
+
         parser.add_argument(
             '--sorry-page-url',
             metavar='<sorry-page-url>',
@@ -577,6 +612,7 @@ class UpdateStagedPolicyConfiguration(command.ShowOne):
             parsed_args.policy,
             algorithm=parsed_args.algorithm,
             persistence=parsed_args.persistence,
+            idle_timeout=parsed_args.idle_timeout,
             sorry_page_url=parsed_args.sorry_page_url,
             certificate_id=parsed_args.certificate_id,
             source_nat=parsed_args.source_nat,
