@@ -242,9 +242,6 @@ class Client(ClientBase):
     gw_interfaces_path = '/gw_interfaces'
     gw_interface_path = '/gw_interfaces/%s'
 
-    vpn_interfaces_path = '/vpn_interfaces'
-    vpn_interface_path = '/vpn_interfaces/%s'
-
     fic_interfaces_path = '/fic_interfaces'
     fic_interface_path = '/fic_interfaces/%s'
 
@@ -254,18 +251,12 @@ class Client(ClientBase):
     internet_services_path = '/internet_services'
     internet_service_path = '/internet_services/%s'
 
-    vpn_services_path = '/vpn_services'
-    vpn_service_path = '/vpn_services/%s'
-
     fic_services_path = '/fic_services'
     fic_service_path = '/fic_services/%s'
 
     internet_gateways_path = '/internet_gateways'
     internet_gateway_path = '/internet_gateways/%s'
 
-    vpn_gateways_path = '/vpn_gateways'
-    vpn_gateway_path = '/vpn_gateways/%s'
-
     fic_gateways_path = '/fic_gateways'
     fic_gateway_path = '/fic_gateways/%s'
 
@@ -359,7 +350,6 @@ class Client(ClientBase):
                      'ipsecpolicies': 'ipsecpolicy',
                      'ikepolicies': 'ikepolicy',
                      'ipsec_site_connections': 'ipsec_site_connection',
-                     'vpnservices': 'vpnservice',
                      'vips': 'vip',
                      'pools': 'pool',
                      'members': 'member',
@@ -503,26 +493,6 @@ class Client(ClientBase):
     def delete_internet_gateway(self, internet_gateway_id):
         return self.delete(self.internet_gateway_path % internet_gateway_id)
 
-    @APIParamsCall
-    def list_vpn_gateways(self, **_params):
-        return self.list('vpn_gateways', self.vpn_gateways_path, **_params)
-
-    @APIParamsCall
-    def show_vpn_gateway(self, vpn_gateway_id, **_params):
-        return self.get(self.vpn_gateway_path % vpn_gateway_id, params=_params)
-
-    @APIParamsCall
-    def create_vpn_gateway(self, body=None):
-        return self.post(self.vpn_gateways_path, body=body)
-
-    @APIParamsCall
-    def update_vpn_gateway(self, vpn_gateway_id, body=None):
-        return self.put(self.vpn_gateway_path % vpn_gateway_id, body=body)
-
-    @APIParamsCall
-    def delete_vpn_gateway(self, vpn_gateway_id):
-        return self.delete(self.vpn_gateway_path % vpn_gateway_id)
-
     @APIParamsCall
     def list_fic_gateways(self, **_params):
         return self.list('fic_gateways', self.fic_gateways_path, **_params)
@@ -604,26 +574,6 @@ class Client(ClientBase):
     def delete_gw_interface(self, gw_interface_id):
         return self.delete(self.gw_interface_path % gw_interface_id)
 
-    @APIParamsCall
-    def list_vpn_interfaces(self, **_params):
-        return self.list('vpn_interfaces', self.vpn_interfaces_path, **_params)
-
-    @APIParamsCall
-    def show_vpn_interface(self, vpn_interface_id, **_params):
-        return self.get(self.vpn_interface_path % vpn_interface_id, params=_params)
-
-    @APIParamsCall
-    def create_vpn_interface(self, body=None):
-        return self.post(self.vpn_interfaces_path, body=body)
-
-    @APIParamsCall
-    def update_vpn_interface(self, vpn_interface_id, body=None):
-        return self.put(self.vpn_interface_path % vpn_interface_id, body=body)
-
-    @APIParamsCall
-    def delete_vpn_interface(self, vpn_interface_id):
-        return self.delete(self.vpn_interface_path % vpn_interface_id)
-
     @APIParamsCall
     def list_fic_interfaces(self, **_params):
         return self.list('fic_interfaces', self.fic_interfaces_path, **_params)
@@ -683,14 +633,6 @@ class Client(ClientBase):
     def show_internet_service(self, internet_service_id, **_params):
         return self.get(self.internet_service_path % internet_service_id, params=_params)
 
-    @APIParamsCall
-    def list_vpn_services(self, **_params):
-        return self.list('vpn_services', self.vpn_services_path, **_params)
-
-    @APIParamsCall
-    def show_vpn_service(self, vpn_service_id, **_params):
-        return self.get(self.vpn_service_path % vpn_service_id, params=_params)
-
     @APIParamsCall
     def list_fic_services(self, **_params):
         return self.list('fic_services', self.fic_services_path, **_params)
