@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import base64
 
 try:
     import json
@@ -32,6 +33,7 @@ UUID_PATTERN = '^[a-f0-9]{8}-?[a-f0-9]{4}-?4[a-f0-9]{3}-?[89ab][a-f0-9]{3}-' \
 
 
 class ListVirtualNetworkAppliance(command.Lister):
+    _description = _("List virtual network appliances")
 
     def get_parser(self, prog_name):
         parser = super(ListVirtualNetworkAppliance, self).get_parser(prog_name)
@@ -71,6 +73,7 @@ class ListVirtualNetworkAppliance(command.Lister):
 
 
 class ShowVirtualNetworkAppliance(command.ShowOne):
+    _description = _("Show virtual network appliance")
 
     def get_parser(self, prog_name):
         parser = super(ShowVirtualNetworkAppliance, self).get_parser(prog_name)
@@ -100,6 +103,7 @@ class ShowVirtualNetworkAppliance(command.ShowOne):
 
 
 class CreateVirtualNetworkAppliance(command.ShowOne):
+    _description = _("Create new virtual network appliance")
 
     def get_parser(self, prog_name):
         parser = super(CreateVirtualNetworkAppliance, self). \
@@ -161,6 +165,13 @@ class CreateVirtualNetworkAppliance(command.ShowOne):
             help=_('Availability zone that virtual network appliance '
                    'will be created'),
         )
+        parser.add_argument(
+            '--initial-config',
+            metavar="<format=enum{set,text},data=file>",
+            help=_("Initial configuration for virtual network appliance "
+                   "format: format of initial configuration data. (set/text)"
+                   "data: file path of initial configuration data."),
+        )
 
         return parser
 
@@ -268,6 +279,36 @@ class CreateVirtualNetworkAppliance(command.ShowOne):
 
                 interface_object.update(tmp)
 
+        initial_config_object = None
+        if parsed_args.initial_config:
+            config_dict = {"format": None, "data": None}
+            for item in parsed_args.initial_config.split(","):
+                parts = item.split('=')
+                if len(parts) == 2:
+                    config_dict[parts[0].strip()] = parts[1].strip()
+
+            config_format = config_dict.get('format')
+            config_path = config_dict.get('data')
+            if not config_format or not config_path:
+                msg = _("You must specify both initial_config.format and initial_config.data (e.g., --initial-config format=set,data=/path/to/config)")
+                raise exceptions.CommandError(msg)
+            if config_format not in ['set', 'text']:
+                msg = _("initial_config.format must be 'set' or 'text'")
+                raise exceptions.CommandError(msg)
+
+            config_data = None
+            try:
+                with open(config_path, 'rb') as f:
+                    config_data = base64.b64encode(f.read()).decode()
+            except OSError as e:
+                msg = "Failed to open/read config file %s: %s"
+                raise exceptions.CommandError(msg % (config_path, e))
+
+            initial_config_object = {
+                'format': config_format,
+                'data': config_data,
+            }
+
         plan_id = \
             parsed_args.virtual_network_appliance_plan_id
 
@@ -290,6 +331,7 @@ class CreateVirtualNetworkAppliance(command.ShowOne):
             default_gateway=default_gateway,
             availability_zone=zone,
             tags=tags,
+            initial_config=initial_config_object,
         )
 
         # Set plan name
@@ -303,6 +345,7 @@ class CreateVirtualNetworkAppliance(command.ShowOne):
 
 
 class DeleteVirtualNetworkAppliance(command.Command):
+    _description = _("Delete virtual network appliance")
 
     def get_parser(self, prog_name):
         parser = super(DeleteVirtualNetworkAppliance, self). \
@@ -324,6 +367,7 @@ class DeleteVirtualNetworkAppliance(command.Command):
 
 
 class UpdateVirtualNetworkApplianceMetaData(command.ShowOne):
+    _description = _("Update meta of virtual network appliance")
 
     def get_parser(self, prog_name):
         parser = super(UpdateVirtualNetworkApplianceMetaData, self). \
@@ -406,6 +450,7 @@ class UpdateVirtualNetworkApplianceMetaData(command.ShowOne):
 
 
 class UpdateVirtualNetworkApplianceInterfaces(command.ShowOne):
+    _description = _("Update interface of virtual network appliance")
 
     def get_parser(self, prog_name):
         parser = super(UpdateVirtualNetworkApplianceInterfaces, self). \
@@ -569,6 +614,7 @@ class UpdateVirtualNetworkApplianceInterfaces(command.ShowOne):
 
 
 class UpdateVirtualNetworkApplianceAAPs(command.ShowOne):
+    _description = _("Update appliance address pair of virtual network appliance")
 
     def get_parser(self, prog_name):
         parser = super(UpdateVirtualNetworkApplianceAAPs, self). \
@@ -729,6 +775,7 @@ class UpdateVirtualNetworkApplianceAAPs(command.ShowOne):
 
 
 class StartVirtualNetworkAppliance(command.Command):
+    _description = _("Start virtual network appliance")
 
     def get_parser(self, prog_name):
         parser = super(StartVirtualNetworkAppliance, self). \
@@ -750,6 +797,7 @@ class StartVirtualNetworkAppliance(command.Command):
 
 
 class StopVirtualNetworkAppliance(command.Command):
+    _description = _("Stop virtual network appliance")
 
     def get_parser(self, prog_name):
         parser = super(StopVirtualNetworkAppliance, self). \
@@ -771,6 +819,7 @@ class StopVirtualNetworkAppliance(command.Command):
 
 
 class RestartVirtualNetworkAppliance(command.Command):
+    _description = _("Restart virtual network appliance")
 
     def get_parser(self, prog_name):
         parser = super(RestartVirtualNetworkAppliance, self). \
@@ -792,6 +841,7 @@ class RestartVirtualNetworkAppliance(command.Command):
 
 
 class ResetPasswordVirtualNetworkAppliance(command.ShowOne):
+    _description = _("Reset password of virtual network appliance")
 
     def get_parser(self, prog_name):
         parser = super(ResetPasswordVirtualNetworkAppliance, self). \
@@ -821,6 +871,7 @@ class ResetPasswordVirtualNetworkAppliance(command.ShowOne):
 
 
 class ShowVirtualNetworkApplianceConsole(command.ShowOne):
+    _description = _("Show console-url of virtual network appliance")
 
     def get_parser(self, prog_name):
         parser = super(ShowVirtualNetworkApplianceConsole, self). \
